@@ -33,7 +33,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
-#include <errno.h>
+#include <cerrno>
 #include <sys/statvfs.h>
 
 // For INT64_MAX:
@@ -136,11 +136,7 @@ void Archiver::setKeptBackups(int num)
 void Archiver::setFilter(const QString &filter)
 {
   filters.clear();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-  const QStringList list = filter.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
   const QStringList list = filter.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
   filters.reserve(list.count());
   for (const QString &str : list)
     filters.append(QRegExp(str, Qt::CaseSensitive, QRegExp::Wildcard));
@@ -164,11 +160,7 @@ QString Archiver::getFilter() const
 void Archiver::setDirFilter(const QString &filter)
 {
   dirFilters.clear();
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-  const QStringList list = filter.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
   const QStringList list = filter.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
   for (const QString &str : list)
   {
     QString expr = str.trimmed();
@@ -566,11 +558,7 @@ bool Archiver::createArchive(const QStringList &includes, const QStringList &exc
       for (const QString &fileName : entryList)
       {
         KIO::UDSEntry entry;
-#if (KIO_VERSION >= QT_VERSION_CHECK(5, 48, 0))
         entry.fastInsert(KIO::UDSEntry::UDS_NAME, fileName);
-#else
-        entry.insert(KIO::UDSEntry::UDS_NAME, fileName);
-#endif
         targetDirList.append(entry);
       }
       jobResult = 0;
